@@ -1,6 +1,6 @@
 /* ncdu - NCurses Disk Usage
 
-  Copyright (c) 2007-2014 Yoran Heling
+  Copyright (c) 2007-2016 Yoran Heling
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -370,6 +370,7 @@ int browse_key(int ch) {
       info_show = 0;
       break;
     case KEY_LEFT:
+    case KEY_BACKSPACE:
     case 'h':
     case '<':
       if(dirlist_par && dirlist_par->parent != NULL) {
@@ -396,7 +397,9 @@ int browse_key(int ch) {
       if(info_show)
         info_show = 0;
       else
-        return 1;
+        if (confirm_quit)
+          quit_init();
+        else return 1;
       break;
     case 'g':
       if(++graph > 3)
