@@ -1,6 +1,6 @@
 /* ncdu - NCurses Disk Usage
 
-  Copyright (c) 2007-2014 Yoran Heling
+  Copyright (c) 2007-2016 Yoran Heling
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -291,10 +291,13 @@ static int process() {
 }
 
 
+extern int confirm_quit_while_scanning_stage_1_passed;
+
 void dir_scan_init(const char *path) {
   dir_curpath_set(path);
   dir_setlasterr(NULL);
   dir_seterr(NULL);
   dir_process = process;
   pstate = ST_CALC;
+  confirm_quit_while_scanning_stage_1_passed = 0;
 }
