@@ -1,6 +1,6 @@
 /* ncdu - NCurses Disk Usage
 
-  Copyright (c) 2007-2014 Yoran Heling
+  Copyright (c) 2007-2016 Yoran Heling
   Shell support: Copyright (c) 2014 Thomas Jarosch
 
   Permission is hereby granted, free of charge, to any person obtaining
@@ -32,6 +32,7 @@
 #include <ncurses.h>
 #include <stdlib.h>
 #include <unistd.h>
+#include <sys/wait.h>
 
 void shell_draw() {
   char *full_path;
@@ -51,9 +52,12 @@ void shell_draw() {
            "Press any key to continue.",
            full_path, res);
   } else {
-    char *shell = getenv("SHELL");
-    if (shell == NULL)
-      shell = DEFAULT_SHELL;
+    char *shell = getenv("NCDU_SHELL");
+    if (shell == NULL) {
+      shell = getenv("SHELL");
+      if (shell == NULL)
+        shell = DEFAULT_SHELL;
+    }
 
     res = system(shell);
 
